/**
   chat: a TCP/IP chatting program
   Copyright (C) 2006  Idan Nof

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   Idan Nof can be reached via -

   email: idannof (at) hotmail (dot) com
   web  : http://www.geocities.com/idannof
   paper: 3 Brande st.,
		  Petach-Tikva, 49600,
		  Israel
*/
package Client;
import java.io.BufferedReader;
import java.io.IOException;

import Util.Config;

/**
 * A thread responsible for sitting on a given port and registering messages receives 
 */
class ServerEchoListener extends Thread {
	/**
	 * An input for the socket
	 */
	private final BufferedReader inSock;

	/**
	 * Read a line from the socket's input
	 * @return The line read
	 */
	ServerEchoListener(BufferedReader inSock) {
		this.inSock = inSock;
	}

	/**
	 * Receives a line over the network
	 * @return The line received
	 */
	private final String getLine() {
		String line = null;
		try {
			line = inSock.readLine();
		} catch (IOException e) {
			System.out.println("Error reading line");
		}
		return line;
	}

	/**
	 * A front-end for this thread.
	 * Read lines from the socket and put it in the server echo FIFO
	 */
	public final void run() {
		int retries=0;
		
		while (true) {
			String line = getLine();
			if (line == null) {
				System.out.println(inSock + ": unexpected end of connection");
				retries++;
				if (retries == Config.max_socket_retries)
					break;
				else
					continue;
			}
			StaticFifos.getServerEcho().put(line);
		}

		StaticFifos.getServerEcho().reset();
		System.out.println(this +": quitting (ServerEchoListener)");
	}

}
