/**
   chat: a TCP/IP chatting program
   Copyright (C) 2006  Idan Nof

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   Idan Nof can be reached via -

   email: idannof (at) hotmail (dot) com
   web  : http://www.geocities.com/idannof
   paper: 3 Brande st.,
		  Petach-Tikva, 49600,
		  Israel
*/
package Server;
import java.io.IOException;
import java.net.ServerSocket;
import java.net.Socket;

import Util.Config;

/**
 * A server waiting for connections
 */
public class Server extends Thread {
	/**
	 * ServerSocket on which the server is working.
	 */
	private final ServerSocket serverSocket;

	/**
	 * Initializes the server and its configuration.
	 * @param server_port The port to listen
	 * @param max_connections Maximum number of concurrent connections to the server
	 */
	public Server(int server_port, int max_connections) throws IOException {
		System.out.println(
			"Server started: server_port="
				+ server_port
				+ ", max_connections="
				+ max_connections
				+ ".");
		serverSocket = new ServerSocket(server_port, max_connections);
	}

	/**
	 * Wait for a client connection
	 * @return The incoming socket request
	 */
	public final Socket listen() {
		System.out.println("waiting for connection()...");
		Socket socket = null;
		try {
			socket = serverSocket.accept();
		} catch (IOException e) {
			System.out.println("Fatal: IOException error in listen()");
		}
		System.out.println("Connection established.");
		return socket;
	}

	/**
	 * A front-end for the server thread.
	 * Wait for incoming sockets and instantiate SocketThread for each.
	 */
	public final void run() {
		while (true) {
			Socket socket = listen();
			new SocketThread(socket).start();
		}
	}

	/**
	 * Main front-end for the server.
	 * Simply start the server thread.
	 * @param args
	 * @throws IOException
	 */
	public static void main(String[] args) throws IOException {
		Server server = new Server(Config.server_port, Config.max_connections);
		new Thread(server).start();
	}
}
