/**
   chat: a TCP/IP chatting program
   Copyright (C) 2006  Idan Nof

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   Idan Nof can be reached via -

   email: idannof (at) hotmail (dot) com
   web  : http://www.geocities.com/idannof
   paper: 3 Brande st.,
		  Petach-Tikva, 49600,
		  Israel
*/
package Server;

import java.util.HashMap;
import java.util.Map;

/**
 * An object describing a session which holds a set of members
 */
public class Session implements Cloneable {
	/**
	 * The identifying name for this session.
	 */
	private final String sessionName;

	/**
	 * The name of the service this session is attached to.
	 */
	private final String serviceName;

	/**
	 *
	 */
	private SessionWrapper sessionWrapper;

	/**
	 * A set holding the members of this session.
	 * Each member is of type User.
	 * 
	 * note: we use HashSet interface here for its clone() implementation.
	 */
	private HashMap users = new HashMap();

	/**
	 * A constructor which saves that identifying session-name and service-name
	 * @param sessionName session-name string
	 * @param serviceName service-name string
	 */
	public Session(String serviceName, String sessionName) {
		this.sessionName = sessionName;
		this.serviceName = "Services." + serviceName;
	}

	/**
	 * Returns the name of this session
	 * @return the name of this session
	 */
	public final String toString() {
		return sessionName;
	}

	/**
	 * Returns a set representing the members of this session. 
	 * Each member is a User instance.
	 * @return a set of User instances
	 */
	public final Map getUsers() {
		return users;
	}

	/**
	 * Create a clone of this object.
	 * The cloning behaves as if based of the standard super class cloning, and cloning
	 * of the 'users' HashSet.
	 */
	public final Object clone() {
		Session s = null;
		try {
			s = (Session) super.clone();
			s.users = (HashMap) this.users.clone();
		} catch (CloneNotSupportedException e) {
			System.out.println(
				"Internal error: ClassNotCloneableException thrown for Session");
		}
		return s;
	}

	/**
	 * Returns the service-name associated with this server session.
	 * @return the service-name associated with this server session.
	 */
	public final String getServiceName() {
		return serviceName;
	}

	/**
	 * Returns the session-name associated with this server session.
	 * @return the session-name associated with this server session.
	 */
	public final String getSessionName() {
		return sessionName;
	}

	/**
	 * Returns the session thread associated with this object
	 * @return the session thread associated with this object
	 */
	public final SessionWrapper getSessionWrapper() {
		return sessionWrapper;
	}

	/**
	 * Sets the session thread associated with this object
	 * @param thread The thread to associate to
	 */
	public final void setSessionWrapper(SessionWrapper thread) {
		sessionWrapper = thread;
	}

}
