/**
   chat: a TCP/IP chatting program
   Copyright (C) 2006  Idan Nof

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   Idan Nof can be reached via -

   email: idannof (at) hotmail (dot) com
   web  : http://www.geocities.com/idannof
   paper: 3 Brande st.,
		  Petach-Tikva, 49600,
		  Israel
*/
package Server;
import java.util.Collection;
import java.util.Iterator;

import Util.Util;

/**
 * A thread class responsible for all of the delivery opeartions on the associated session
 */
public class SessionWrapper {
	/**
	 * The cloned session instance associated with this session thread
	 */
	private Session session;

	/**
	 * Construct a new object by synchronizing a new object
	 * @param session The session to synchronize
	 */
	SessionWrapper(Session session) {
		synchronizeSession(session);
	}

	/**
	 * Clone the local session to match a given session
	 * @param session The session to clone
	 */
	public final void synchronizeSession(Session session) {
		/**
		 * synchronize to disallow concurrent reading by other methods
		 */
		synchronized (session) {
			this.session = (Session) session.clone();
		}
	}

	/**
	 * Send a new message to all members of this session
	 * @param socketThread The sending socket thread
	 * @param msg The message to send
	 */
	public final void newMessage(SocketThread socketThread, String msg) {
		/**
		 * synchronize to disallow concurrent modification by other methods
		 */
		synchronized (session) {
			String s = socketThread.getUser().toString() + ": " + msg;
			Collection users = session.getUsers().values();

			// iterate over all users members of this session
			Iterator it = users.iterator();
			while (it.hasNext()) {
				User nextUser = (User) it.next();
				SocketThread nextSocketThread = nextUser.getSocketThread();
				Util.sendLine(s, nextSocketThread.getSockOut());
			} // iterate over all elements
		}
	}

}
