/**
   chat: a TCP/IP chatting program
   Copyright (C) 2006  Idan Nof

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   Idan Nof can be reached via -

   email: idannof (at) hotmail (dot) com
   web  : http://www.geocities.com/idannof
   paper: 3 Brande st.,
		  Petach-Tikva, 49600,
		  Israel
*/
package Util;
import java.util.LinkedList;

/**
 * 
 */
public class SynchedFifo {
	/**
	 * A list holding messages. It is first-in first-out based: 
	 * items are put on its end, and are being recovered from its start. 
	 */
	private final LinkedList fifo = new LinkedList();

	/**
	 * Put a message in the end of the fifo.
	 * @param msg The message to put
	 */
	synchronized public final void put(String msg) {
		if (msg==null) return;
		fifo.addLast(new String(msg));
		this.notifyAll();
	}

	/**
	 * Retrieve a message from the start of the fifo. The item is removed from the fifo.
	 * @return The retrieved message
	 */
	synchronized public final String get() {
		String s = (String) fifo.getFirst();
		fifo.removeFirst();
		return s;
	}

	/**
	 * Clears the fifo content
	 */
	synchronized public final void reset() {
		fifo.clear();
	}

	/**
	 * A predicate the checks if the fifo is empty
	 * @return True if empty
	 */
	synchronized public final boolean isEmpty() {
		return (fifo.size() == 0);
	}
	
	/**
	 * Wait for a given fifo
	 * @param o The object to wait for
	 */
	/*static public void waitForFifo(SynchedFifo fifo)) {
		synchronized (fifo) {
			try {
				while (!isEmpty()) {
					fifo.wait();
				}
			} catch (InterruptedException e) {
				System.out.println("Blocking interrupted.");
			}
		}
	}*/
}