/**
   chat: a TCP/IP chatting program
   Copyright (C) 2006  Idan Nof

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   Idan Nof can be reached via -

   email: idannof (at) hotmail (dot) com
   web  : http://www.geocities.com/idannof
   paper: 3 Brande st.,
		  Petach-Tikva, 49600,
		  Israel
*/
package Util;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.IOException;
import java.net.Socket;

/**
 * Network static utility functions
 */
public final class Util {
	/**
	 * Print a formatted description of a given socket
	 * @param s The given socket
	 */
	public static void printFormattedSocketName(Socket s) {
		System.out.println(
			"local: host "
				+ s.getLocalAddress()
				+ ", port "
				+ s.getLocalPort());
		System.out.println(
			"remote: host "
				+ s.getInetAddress()
				+ ", port "
				+ s.getPort());
	}
	
	/**
	 * Read a line from BufferedReader 'read'
	 * @return The line read
	 */
	public static String recvLine(BufferedReader read) {
		String line = null;
		try {
			line = read.readLine();
		} catch (IOException e) {
			System.out.println("Error reading line");
		}
		return line;
	}
	
	/**
	 * Sends a single line over the network.
	 * The method writes the string s, writes a newline, and flushes the output stream.
	 * @param s The line to send
	 */
	public static void sendLine(String s, BufferedWriter write) {
		try {
			write.write(s);
			write.newLine();
			write.flush();
		} catch (IOException e) {
			System.out.println("Error sending line.");
		}
	}
	
	/**
	 * Wait for a given object
	 * @param o The object to wait for
	 */
	static public void waitFor(Object o) {
		synchronized (o) {
			try {
				o.wait();
			} catch (InterruptedException e) {
				System.out.println("Blocking interrupted.");
			}
		}
	}
}
